@@ -1,7 +1,7 @@
-from agiflow.opentelemetry.span_processors import ThreadPoolSpanProcessor
-from agiflow.opentelemetry.trace_exporter import OTLPJsonSpanExporter
-from agiflow.opentelemetry.trace_sampler import NoSampler
-from agiflow.opentelemetry.trace_decorators import (
+from .span_processors import ThreadPoolSpanProcessor
+from .trace_exporter import OTLPJsonSpanExporter
+from .trace_sampler import NoSampler
+from .trace_decorators import (
   task,
   atask,
   agent,
@@ -11,9 +11,9 @@ from agiflow.opentelemetry.trace_decorators import (
   workflow,
   aworkflow
 )
-from agiflow.opentelemetry.tracing.tracing import TracerWrapper
-from agiflow.opentelemetry.tracing.context_manager import get_tracer
-from agiflow.opentelemetry.context import (
+from .tracing.tracing import TracerWrapper
+from .tracing.context_manager import get_tracer
+from .context import (
   get_trace_context_from_carrier,
   get_carrier_from_trace_context,
   set_association_properties,
