@@ -5,14 +5,14 @@ from opentelemetry.trace import Span
 from opentelemetry.trace.propagation.tracecontext import TraceContextTextMapPropagator
 from opentelemetry.context import get_current, set_value
 from agiflow.opentelemetry.convention import SpanAttributes
-from agiflow.opentelemetry.context.constants import ContextKeys
-from agiflow.opentelemetry.context.context import (
+from .constants import ContextKeys
+from .context import (
     set_association_properties,
     set_prompt_settings_context,
     set_workflow_name,
     set_override_enable_context_tracing,
 )
-from agiflow.opentelemetry.context.span_from_context import (
+from .span_from_context import (
     set_prompt_attributes_from_context,
     set_workflow_name_from_context,
 )
