@@ -14,6 +14,14 @@ from .agiflow_attributes import (
   AgiflowSpanAttributes,
   AgiflowSpanAttributesValidator
 )
+from .gen_ai_span_attributes import (
+  GenAISpanAttributes,
+  GenAISpanAttributesValidator,
+)
+from .gen_ai_span_events import (
+  GenAISpanEvents,
+  GenAISpanEventAttributes,
+)
 from .constants import (
   Event,
   OpenAIMethods,
@@ -29,7 +37,13 @@ from .constants import (
 )
 
 
-class SpanAttributes(AgiflowSpanAttributes, LLMSpanAttributes, FrameworkSpanAttributes, DatabaseSpanAttributes):
+class SpanAttributes(
+    AgiflowSpanAttributes,
+    LLMSpanAttributes,
+    FrameworkSpanAttributes,
+    DatabaseSpanAttributes,
+    GenAISpanAttributes
+):
     """
     All span attributes collected by Agiflow.
     Using this for key value instead of hard coding to ensure
@@ -53,6 +67,8 @@ __all__ = [
   'AgiflowSpanAttributesValidator',
   'AgiflowSpanAttributes',
   'AgiflowServiceTypes',
+  'GenAISpanAttributesValidator',
+  'GenAISpanAttributes',
   "LLMTypes",
   "LLMPromptKeys",
   "LLMPromptRoles",
@@ -60,4 +76,6 @@ __all__ = [
   "LLMTokenUsageKeys",
   "SpanAttributes",
   "WeaviateMethods",
+  "GenAISpanEvents",
+  "GenAISpanEventAttributes",
   ]
