@@ -12,6 +12,8 @@ class AgiflowSpanAttributes:
     AGIFLOW_SERVICE_TYPE = 'agiflow.service.type'
     # Library version
     AGIFLOW_SERVICE_VERSION = 'agiflow.service.version'
+    # Set span as root of feedback rather than top parent span
+    AGIFLOW_FEEDBACK_ROOT = "agiflow.feedback.root"
 
     # Function or class name
     AGIFLOW_ENTITY_NAME = "agiflow.entity.name"
