@@ -1,4 +1,4 @@
-from agiflow.opentelemetry.instrumentation.chroma.instrumentation import (
+from .instrumentation import (
   ChromaInstrumentation,
 )
 
