@@ -14,7 +14,7 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
-from agiflow.opentelemetry.convention.constants import LLMTokenUsageKeys, LLMTypes
+from agiflow.opentelemetry.convention.constants import LLMTypes
 from agiflow.opentelemetry.convention.llm_span_attributes import LLMSpanAttributesValidator
 from agiflow.opentelemetry.instrumentation.constants.cohere import APIS
 from agiflow.utils import serialise_to_json
@@ -34,17 +34,16 @@ class EmbedSpanCapture(CohereSpanCapture):
         self.model = model
 
     @staticmethod
-    def get_span_name(instance):
+    def get_span_name(instance, *args, **kwargs):
         return APIS["EMBED"]["METHOD"]
 
     def capture_input(self):
         span_attributes = {
           SpanAttributes.AGIFLOW_SERVICE_TYPE: AgiflowServiceTypes.LLM,
-          SpanAttributes.LLM_TYPE: LLMTypes.EMBEDDING,
+          SpanAttributes.GEN_AI_OPERATION_NAME: LLMTypes.EMBEDDING,
           SpanAttributes.URL_FULL: APIS["EMBED"]["URL"],
           SpanAttributes.LLM_API: APIS["EMBED"]["ENDPOINT"],
-          SpanAttributes.LLM_MODEL: self.model,
-          SpanAttributes.LLM_PROMPTS: "",
+          SpanAttributes.GEN_AI_REQUEST_MODEL: self.model,
           SpanAttributes.LLM_EMBEDDING_DATASET_ID: self.fkwargs.get("dataset_id"),
           SpanAttributes.LLM_EMBEDDING_JOB_NAME: self.fkwargs.get("name"),
         }
@@ -66,27 +65,5 @@ class EmbedSpanCapture(CohereSpanCapture):
             ):
                 usage = result.meta.billed_units
                 if usage is not None:
-                    usage_dict = {
-                        LLMTokenUsageKeys.PROMPT_TOKENS: (
-                            usage.input_tokens
-                            if usage.input_tokens is not None
-                            else 0
-                        ),
-                        LLMTokenUsageKeys.COMPLETION_TOKENS: (
-                            usage.output_tokens
-                            if usage.output_tokens is not None
-                            else 0
-                        ),
-                        LLMTokenUsageKeys.TOTAL_TOKENS: (
-                            usage.input_tokens + usage.output_tokens
-                            if usage.input_tokens is not None
-                            and usage.output_tokens is not None
-                            else 0
-                        ),
-                        LLMTokenUsageKeys.SEARCH_UNITS: (
-                            usage.search_units
-                            if usage.search_units is not None
-                            else 0
-                        ),
-                    }
-                    self.set_span_attribute(SpanAttributes.LLM_TOKEN_COUNTS, serialise_to_json(usage_dict))
+                    self.set_span_attribute(SpanAttributes.GEN_AI_USAGE_INPUT_TOKENS, usage.input_tokens)
+                    self.set_span_attribute(SpanAttributes.GEN_AI_USAGE_OUTPUT_TOKENS, usage.output_tokens)
