@@ -1,4 +1,4 @@
-from agiflow.opentelemetry.instrumentation.groq.hooks.chat_completion import (
+from .chat_completion import (
   ChatCompletionSpanCapture,
 )
 
