@@ -1,4 +1,4 @@
-from agiflow.opentelemetry.instrumentation.langchain.instrumentation import (
+from .instrumentation import (
   LangchainInstrumentation,
 )
 
