@@ -1,4 +1,4 @@
-from agiflow.opentelemetry.instrumentation.langchain_community.instrumentation import (
+from .instrumentation import (
   LangchainCommunityInstrumentation,
 )
 
