@@ -22,15 +22,17 @@ from opentelemetry.trace import get_tracer
 from agiflow.opentelemetry.instrumentation.utils import (
   method_wrapper,
   async_method_wrapper,
-)
-
-from agiflow.opentelemetry.instrumentation.langchain_core.hooks import (
-  GenericSpanCapture,
-  RunnableSpanCapture,
-  LLMSpanCapture,
+  stream_wrapper,
+  async_stream_wrapper
 )
 from agiflow.opentelemetry.instrumentation.utils import patch_module_classes
 from agiflow.version import __version__
+from .hooks import (
+  GenericSpanCapture,
+  RunnableSpanCapture,
+  LLMSpanCapture,
+  LLMStreamSpanCapture
+)
 
 
 class LangchainCoreInstrumentation(BaseInstrumentor):
@@ -109,5 +111,23 @@ class LangchainCoreInstrumentation(BaseInstrumentor):
             )
         )
 
+        wrap_function_wrapper(
+            "langchain_core.language_models.llms",
+            "BaseLLM.stream",
+            stream_wrapper(
+              tracer=tracer,
+              SpanCapture=LLMStreamSpanCapture
+            )
+        )
+
+        wrap_function_wrapper(
+            "langchain_core.language_models.llms",
+            "BaseLLM.astream",
+            async_stream_wrapper(
+              tracer=tracer,
+              SpanCapture=LLMStreamSpanCapture
+            )
+        )
+
     def _uninstrument(self, **kwargs):
         pass
