@@ -1,4 +1,4 @@
-from agiflow.opentelemetry.instrumentation.llamaindex.instrumentation import (
+from .instrumentation import (
   LlamaIndexInstrumentation,
 )
 
