@@ -49,13 +49,16 @@ class OpenAISpanCapture(BaseSpanCapture):
             else ""
         )
         service_provider = SERVICE_PROVIDERS["OPENAI"]
+        if service_provider is not None:
+            system = service_provider.lower()
 
         attr = {
             SpanAttributes.AGIFLOW_SERVICE_NAME: service_provider,
             SpanAttributes.AGIFLOW_SERVICE_VERSION: self.version,
             SpanAttributes.AGIFLOW_SERVICE_TYPE: AgiflowServiceTypes.LLM,
             SpanAttributes.URL_FULL: base_url,
-            SpanAttributes.LLM_MODEL: self.model,
+            SpanAttributes.GEN_AI_REQUEST_MODEL: self.model,
+            SpanAttributes.GEN_AI_SYSTEM: system,
         }
 
         try:
