@@ -14,7 +14,7 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
-from typing import Any, Dict
+from typing import Any, Dict, List
 
 from agiflow.opentelemetry.instrumentation.constants.openai import APIS
 from opentelemetry.trace.status import StatusCode
@@ -34,6 +34,8 @@ from .utils import extract_content
 
 
 class ChatCompletionSpanCapture(OpenAILLMSpanCapture):
+    finish_reasons: List[str] = []
+
     def __init__(
         self,
         *args,
@@ -41,15 +43,38 @@ class ChatCompletionSpanCapture(OpenAILLMSpanCapture):
     ):
         super().__init__(*args, **kwargs)
 
+    @staticmethod
+    def get_span_name(instance, *args, **kwargs):
+        """
+        Override this method if span name is different
+        """
+        if kwargs.get('model'):
+            return f"{LLMTypes.CHAT.value.lower()} {kwargs.get('model')}"
+        if instance is None:
+            return ""
+        if hasattr(instance, '__class__'):
+            if hasattr(instance, '__name__'):
+                return f"{instance.__class__.__name__}.${instance.__name__}"
+            else:
+                return f"{instance.__class__.__name__}"
+        elif hasattr(instance, '__name__'):
+            return f"{instance.__name__}"
+        else:
+            return ""
+
     def capture_input(self):
         self.add_input_attributes()
         span_attributes: Dict[str, Any] = {
           SpanAttributes.LLM_API: APIS["CHAT_COMPLETION"]["ENDPOINT"],
-          SpanAttributes.LLM_TYPE: LLMTypes.CHAT,
+          SpanAttributes.GEN_AI_OPERATION_NAME: LLMTypes.CHAT,
         }
+
+        if self.fkwargs.get('model'):
+            span_attributes[SpanAttributes.GEN_AI_REQUEST_MODEL] = self.fkwargs.get('model')
+
         if should_send_prompts():
             # handle tool calls in the kwargs
-            llm_prompts = []
+            prompts = []
             for item in (self.messages or []):
                 if hasattr(item, "tool_calls") and item.tool_calls is not None:
                     tool_calls = []
@@ -72,11 +97,11 @@ class ChatCompletionSpanCapture(OpenAILLMSpanCapture):
                                 ),
                             }
                         tool_calls.append(tool_call_dict)
-                    llm_prompts.append(tool_calls)
+                    prompts.append(tool_calls)
                 else:
-                    llm_prompts.append(item)
+                    prompts.append(item)
 
-            span_attributes[SpanAttributes.LLM_PROMPTS] = serialise_to_json(llm_prompts)
+            self.set_prompt_span_event(prompts)
 
         self.set_span_attributes_from_pydantic(
           span_attributes,
@@ -84,25 +109,34 @@ class ChatCompletionSpanCapture(OpenAILLMSpanCapture):
           )
 
     def capture_output(self, result):
-        self.set_span_attribute(SpanAttributes.LLM_MODEL, result.model)
+        self.set_span_attribute(SpanAttributes.GEN_AI_RESPONSE_MODEL, result.model)
 
         if should_send_prompts():
             if hasattr(result, "choices") and result.choices is not None:
                 responses = []
+                finish_reasons = []
                 for choice in result.choices:
                     response = extract_content(choice)
+                    if hasattr(choice, 'finish_reason') and choice.finish_reason is not None:
+                        finish_reasons.append(choice.finish_reason)
                     if response:
                         responses.append(response)
 
-                self.set_span_attribute(SpanAttributes.LLM_RESPONSES, serialise_to_json(responses))
+                self.set_completion_span_event(responses)
+                self.set_span_attribute(SpanAttributes.GEN_AI_RESPONSE_FINISH_REASONS, finish_reasons)
             else:
                 responses = []
-                self.set_span_attribute(SpanAttributes.LLM_RESPONSES, serialise_to_json(responses))
+                self.set_completion_span_event(responses)
 
         if (
             hasattr(result, "system_fingerprint")
             and result.system_fingerprint is not None
         ):
+            if result.system_fingerprint == 'fp_ollama':
+                self.set_span_attribute(
+                    SpanAttributes.GEN_AI_SYSTEM, 'ollama'
+                )
+
             self.set_span_attribute(
                 SpanAttributes.LLM_SYSTEM_FINGERPRINT, result.system_fingerprint
             )
@@ -111,12 +145,8 @@ class ChatCompletionSpanCapture(OpenAILLMSpanCapture):
         if hasattr(result, "usage"):
             usage = result.usage
             if usage is not None:
-                usage_dict = {
-                    LLMTokenUsageKeys.PROMPT_TOKENS: usage.prompt_tokens,
-                    LLMTokenUsageKeys.COMPLETION_TOKENS: usage.completion_tokens,
-                    LLMTokenUsageKeys.TOTAL_TOKENS: usage.total_tokens,
-                }
-                self.set_span_attribute(SpanAttributes.LLM_TOKEN_COUNTS, serialise_to_json(usage_dict))
+                self.set_span_attribute(SpanAttributes.GEN_AI_USAGE_INPUT_TOKENS, usage.prompt_tokens)
+                self.set_span_attribute(SpanAttributes.GEN_AI_USAGE_OUTPUT_TOKENS, usage.completion_tokens)
 
     def get_prompt_tokens(self, result):
         # iterate over kwargs.get("messages", {}) and calculate the prompt tokens
@@ -139,12 +169,14 @@ class ChatCompletionSpanCapture(OpenAILLMSpanCapture):
         function_call = self.fkwargs.get('functions')
         tool_calls = self.fkwargs.get('tools')
         if hasattr(chunk, "model") and chunk.model is not None:
-            self.span.set_attribute(SpanAttributes.LLM_MODEL, chunk.model)
+            self.span.set_attribute(SpanAttributes.GEN_AI_RESPONSE_MODEL, chunk.model)
 
         content = []
         if hasattr(chunk, "choices") and chunk.choices is not None:
             if not function_call and not tool_calls:
                 for choice in chunk.choices:
+                    if hasattr(choice, 'finish_reason') and choice.finish_reason is not None:
+                        self.finish_reasons.append(choice.finish_reason)
                     if choice.delta and choice.delta.content is not None:
                         token_counts = estimate_tokens(choice.delta.content)
                         completion_tokens = self.tokens.get(LLMTokenUsageKeys.COMPLETION_TOKENS, 0)
@@ -202,32 +234,20 @@ class ChatCompletionSpanCapture(OpenAILLMSpanCapture):
     def capture_stream_end(self, result, result_content):
         prompt_tokens = self.get_prompt_tokens(result)
         # Finalize span after processing all chunks
-        self.span.add_event(Event.STREAM_END)
-        self.span.set_attribute(
-            SpanAttributes.LLM_TOKEN_COUNTS,
-            serialise_to_json(
+        self.set_span_attribute(SpanAttributes.GEN_AI_USAGE_INPUT_TOKENS, prompt_tokens)
+        self.set_span_attribute(SpanAttributes.GEN_AI_USAGE_OUTPUT_TOKENS, self.tokens[
+                      LLMTokenUsageKeys.COMPLETION_TOKENS
+                      ])
+        self.set_completion_span_event(
+            [
                 {
-                    LLMTokenUsageKeys.PROMPT_TOKENS: prompt_tokens,
-                    LLMTokenUsageKeys.COMPLETION_TOKENS: self.tokens[
-                      LLMTokenUsageKeys.COMPLETION_TOKENS
-                      ],
-                    LLMTokenUsageKeys.TOTAL_TOKENS: prompt_tokens + self.tokens[
-                      LLMTokenUsageKeys.COMPLETION_TOKENS
-                      ],
+                    LLMResponseKeys.ROLE: "assistant",
+                    LLMResponseKeys.CONTENT: "".join(result_content),
                 }
-            ),
-        )
-        self.span.set_attribute(
-            SpanAttributes.LLM_RESPONSES,
-            serialise_to_json(
-                [
-                    {
-                        LLMResponseKeys.ROLE: "assistant",
-                        LLMResponseKeys.CONTENT: "".join(result_content),
-                    }
-                ]
-            ),
+            ]
         )
+        self.set_span_attribute(SpanAttributes.GEN_AI_RESPONSE_FINISH_REASONS, self.finish_reasons)
+        self.span.add_event(Event.STREAM_END)
         self.span.set_status(StatusCode.OK)
         self.span.end()
 
