@@ -1,4 +1,4 @@
-from agiflow.opentelemetry.instrumentation.pinecone.instrumentation import (
+from .instrumentation import (
   PineconeInstrumentation,
 )
 
