@@ -1,4 +1,4 @@
-from agiflow.opentelemetry.instrumentation.qdrant.instrumentation import (
+from .instrumentation import (
   QdrantInstrumentation,
 )
 
