@@ -1,4 +1,4 @@
-from agiflow.opentelemetry.instrumentation.qdrant.hooks.collection import (
+from .collection import (
   CollectionCallSpanCapture
 )
 
