@@ -39,6 +39,7 @@ class ThreadPoolSpanProcessor(SpanProcessor):
         self.max_queue_size = max_queue_size
         self.futures = deque([], pool_queue_size)
         self.span_exporter = span_exporter
+        self.pool_size = pool_size
         self.queue = []
         # Wait for all requests to be finished before shutdown
         try:
@@ -53,12 +54,21 @@ class ThreadPoolSpanProcessor(SpanProcessor):
     ) -> None:
         pass
 
+    def renew_pool(self):
+        try:
+            self.pool._check_running()
+        except Exception as e:
+            logger.warn(e)
+            self.pool = Pool(self.pool_size)
+
     def on_end(self, span: ReadableSpan) -> None:
         token = attach(set_value(_SUPPRESS_INSTRUMENTATION_KEY, True))
         self.queue.append(span)
+        self.renew_pool()
         if len(self.queue) == self.max_queue_size:
-            self.futures.append(self.pool.apply_async(self._export, self.queue))
+            chunk = self.queue.copy()
             self.queue = []
+            self.futures.append([self.pool.apply_async(self._export, chunk), chunk])
         detach(token)
 
     def shutdown(self) -> None:
@@ -68,18 +78,26 @@ class ThreadPoolSpanProcessor(SpanProcessor):
         self.span_exporter.export(seq)
 
     def force_flush(self, timeout_millis: int = 30000) -> bool:
+        self.renew_pool()
         if len(self.queue) != 0:
-            self.futures.append(self.pool.apply_async(self._export, self.queue))
+            chunk = self.queue.copy()
             self.queue = []
+            self.futures.append([self.pool.apply_async(self._export, chunk), chunk])
         # pylint: disable=unused-argument
         return True
 
     def wait_for_flush(self):
-        try:
-            for future in self.futures:
+        result_list = []
+        while len(self.futures) != 0:
+            result_list.append(self.futures.pop())
+        for [future, chunk] in result_list:
+            try:
                 res = future.get()
                 logger.info(res)
-        except Exception as e:
-            logger.error(e)
-
-        self.futures = []
+            except Exception as e:
+                logger.error(e)
+                try:
+                    self._export(chunk)
+                except Exception as e:
+                    logger.info('Failed to send trace')
+                    logger.error(e)
