@@ -1,6 +1,6 @@
-from agiflow.opentelemetry.trace_decorators.task import task, atask, agent, aagent, tool, atool
-from agiflow.opentelemetry.trace_decorators.workflow import workflow, aworkflow
-from agiflow.opentelemetry.trace_decorators.wrapper import (
+from .task import task, atask, agent, aagent, tool, atool
+from .workflow import workflow, aworkflow
+from .wrapper import (
   BaseSpanCapture,
   decorate_method,
   adecorate_method,
