@@ -11,9 +11,6 @@ from agiflow.opentelemetry.instrumentation.constants.common import (
 )
 from opentelemetry import baggage
 from agiflow.version import __version__
-from agiflow.opentelemetry.trace_decorators.helper import (
-    SharedKwargsWithHooks,
-)
 from agiflow.opentelemetry.tracing import get_tracer, TracerWrapper
 from agiflow.opentelemetry.utils import (
     should_send_prompts,
@@ -26,6 +23,9 @@ from agiflow.utils import (
   serialise_to_json,
   camel_to_snake
 )
+from .helper import (
+    SharedKwargsWithHooks,
+)
 
 R = TypeVar('R')
 logger = logging.getLogger(__name__)
@@ -371,7 +371,7 @@ def decorate_class_method(
             cls,
             method_name,
             decorate_method(
-              name=task_name,
+              name=f"{task_name}.{method_name}",
               tlp_service_type=tlp_service_type,
               span_kind=span_kind,
               SpanCapture=SpanCapture,
@@ -400,7 +400,7 @@ def adecorate_class_method(
             cls,
             method_name,
             adecorate_method(
-              name=task_name,
+              name=f"{task_name}.{method_name}",
               tlp_service_type=tlp_service_type,
               span_kind=span_kind,
               SpanCapture=SpanCapture,
