@@ -58,7 +58,7 @@ logger = logging.getLogger(__name__)
 class TracerWrapper(object):
     """
     Singleton class which store reference to
-    trace_provider, spans_processor, etc...
+    trace_provider, span_processor, etc...
     """
     enable_content_tracing: bool = True
     resource_attributes: dict = {}
@@ -67,9 +67,10 @@ class TracerWrapper(object):
     __resource: Resource
     __sampler: Optional[Sampler]
     __tracer_provider: TracerProvider
-    __spans_processor: SpanProcessor
+    __span_processor: SpanProcessor
+    __additional_span_processor: SpanProcessor = None
     __content_allow_list: ContentAllowList
-    __spans_processor_original_on_start: Optional[Callable] = None
+    __span_processor_original_on_start: Optional[Callable] = None
 
     def __new__(
         cls,
@@ -78,6 +79,7 @@ class TracerWrapper(object):
         extra_instrumentations: Optional[List[type[BaseInstrumentor]]] = None,
         exporter: Optional[SpanExporter] = None,
         Processor: Optional[type[SpanProcessor]] = None,
+        additional_processor: Optional[SpanProcessor] = None,
         sampler: Optional[Sampler] = None
     ) -> "TracerWrapper":
         if not hasattr(cls, "instance"):
@@ -92,6 +94,9 @@ class TracerWrapper(object):
                 sampler=obj.__sampler,
             )
 
+            if additional_processor is not None:
+                obj.__additional_span_processor = additional_processor
+
             if Processor is None:
                 Processor = BatchSpanProcessor
 
@@ -99,13 +104,19 @@ class TracerWrapper(object):
                 span_exporter = init_spans_exporter(
                     TracerWrapper.endpoint, TracerWrapper.headers
                 )
-                obj.__spans_processor = Processor(span_exporter)
+                obj.__span_processor = Processor(span_exporter)
             else:
-                obj.__spans_processor = Processor(exporter)
+                obj.__span_processor = Processor(exporter)
 
-            obj.__spans_processor.on_start = obj._span_processor_on_start
+            if hasattr(obj.__span_processor, 'on_start'):
+                obj.__span_processor.on_start = obj._span_processor_on_start
 
-            obj.__tracer_provider.add_span_processor(obj.__spans_processor)
+            obj.__tracer_provider.add_span_processor(obj.__span_processor)
+
+            if obj.__additional_span_processor is not None:
+                if hasattr(obj.__additional_span_processor, 'on_start'):
+                    obj.__additional_span_processor.on_start = obj._span_processor_on_start
+                obj.__tracer_provider.add_span_processor(obj.__additional_span_processor)
 
             if propagator:
                 set_global_textmap(propagator)
@@ -144,8 +155,8 @@ class TracerWrapper(object):
         set_prompt_attributes_from_context(span)
 
         # Call original on_start method if it exists in custom processor
-        if self.__spans_processor_original_on_start:
-            self.__spans_processor_original_on_start(span, parent_context)
+        if self.__span_processor_original_on_start:
+            self.__span_processor_original_on_start(span, parent_context)
 
     @staticmethod
     def set_static_params(
@@ -171,7 +182,18 @@ class TracerWrapper(object):
         return False
 
     def flush(self):
-        self.__spans_processor.force_flush()
+        self.__span_processor.force_flush()
+
+        if self.__additional_span_processor is not None:
+            self.__additional_span_processor.force_flush()
+
+    def wait_for_flush(self):
+        if hasattr(self.__span_processor, 'wait_for_flush'):
+            self.__span_processor.wait_for_flush()
+
+        if self.__additional_span_processor is not None:
+            if hasattr(self.__additional_span_processor, 'wait_for_flush'):
+                self.__additional_span_processor.wait_for_flush()
 
     def get_tracer(self):
         return self.__tracer_provider.get_tracer(TRACER_NAME, __version__)
