@@ -21,8 +21,8 @@ class Telemetry:
 
             if obj._telemetry_enabled:
                 obj._posthog = Posthog(
-                    project_api_key="phc_nsDxxaVGqYFOmxWsUpTY2hOuxSlk6gDLe4LPYEF8oEw",
-                    host="https://app.posthog.com",
+                    project_api_key="phc_dNE4sEUFxMaQlBq8rDByVKpB1FNzouM2OEqBtRNHT09",
+                    host="https://us.i.posthog.com",
                 )
                 obj._curr_anon_id = None
 
